@@ -22,10 +22,10 @@ from zope.i18n import translate
 from z3c.saconfig import Session
 from zExceptions import NotFound
 from plonetheme.nuplone.utils import formatDate
-from euphorie.client.survey import PathGhost
+from ..ghost import PathGhost
+from .. import MessageFactory as _
 from euphorie.client.interfaces import IIdentificationPhaseSkinLayer
 from euphorie.client.interfaces import IReportPhaseSkinLayer
-from euphorie.client import MessageFactory as _
 from euphorie.client.session import SessionManager
 from euphorie.client import model
 from euphorie.client.company import CompanySchema
@@ -354,10 +354,10 @@ class IdentificationReportDownload(grok.View):
         comment_style = document.StyleSheet.ParagraphStyles.Comment
         header_styles = {
                 0: document.StyleSheet.ParagraphStyles.Heading2,
-                1:  document.StyleSheet.ParagraphStyles.Heading3,
-                2:  document.StyleSheet.ParagraphStyles.Heading4,
-                3:  document.StyleSheet.ParagraphStyles.Heading5,
-                4:  document.StyleSheet.ParagraphStyles.Heading6,
+                1: document.StyleSheet.ParagraphStyles.Heading3,
+                2: document.StyleSheet.ParagraphStyles.Heading4,
+                3: document.StyleSheet.ParagraphStyles.Heading5,
+                4: document.StyleSheet.ParagraphStyles.Heading6,
                 }
 
         for node in self.getNodes():
@@ -673,7 +673,7 @@ class ActionPlanReportDownload(grok.View):
                 else:
                     level = node.priority
                 section.append(Paragraph(normal_style,
-                    t(_("report_priority", default=u"This is a ")), level))
+                    t(_("report_priority", default=u"This is a ")), level, u'.'))
 
             for el in HtmlToRtf(zodb_node.description, normal_style):
                 section.append(el)
